pub enum AdbError {
NotFound(String),
CommandFailed(String),
Timeout,
DeviceNotFound(String),
}Expand description
Errors produced by ADB operations.
Variants
NotFound(String)
The adb binary could not be found or spawned.
CommandFailed(String)
An ADB command was launched but exited with a non-zero status.
Timeout
An ADB command timed out.
DeviceNotFound(String)
No device (or the requested device) could be found.